@@ -8,7 +8,6 @@ SPDX-License-Identifier: GPL-2.0-or-later
 
 #include <QCommandLineParser>
 #include <QDateTime>
-#include <QSessionManager>
 #include <QSurfaceFormat>
 
 #include <iostream>
@@ -101,6 +100,9 @@ int main(int argc, char *argv[])
     format.setOption(QSurfaceFormat::ResetNotification);
     QSurfaceFormat::setDefaultFormat(format);
 
+    // disable session management for the greeter
+    QCoreApplication::setAttribute(Qt::AA_DisableSessionManager);
+
     ScreenLocker::UnlockApp app(argc, argv);
 
     KSignalHandler::self()->watchSignal(SIGTERM);
@@ -117,13 +119,6 @@ int main(int argc, char *argv[])
     QCoreApplication::setApplicationVersion(QStringLiteral("0.1"));
     QCoreApplication::setOrganizationDomain(QStringLiteral("kde.org"));
 
-    // disable session management for the greeter
-    auto disableSessionManagement = [](QSessionManager &sm) {
-        sm.setRestartHint(QSessionManager::RestartNever);
-    };
-    QObject::connect(&app, &QGuiApplication::commitDataRequest, disableSessionManagement);
-    QObject::connect(&app, &QGuiApplication::saveStateRequest, disableSessionManagement);
-
     QCommandLineParser parser;
     parser.setApplicationDescription(i18n("Greeter for the KDE Plasma Workspaces Screen locker"));
     parser.addHelpOption();
@@ -142,7 +137,6 @@ int main(int argc, char *argv[])
                                        QStringLiteral("milliseconds"),
                                        QStringLiteral("0"));
     QCommandLineOption nolockOption(QStringLiteral("nolock"), i18n("Don't show any lock user interface."));
-    QCommandLineOption switchUserOption(QStringLiteral("switchuser"), i18n("Default to the switch user UI."));
 
     QCommandLineOption waylandFdOption(QStringLiteral("ksldfd"), i18n("File descriptor for connecting to ksld."), QStringLiteral("fd"));
 
@@ -151,7 +145,6 @@ int main(int argc, char *argv[])
     parser.addOption(immediateLockOption);
     parser.addOption(graceTimeOption);
     parser.addOption(nolockOption);
-    parser.addOption(switchUserOption);
     parser.addOption(waylandFdOption);
     parser.process(app);
 
@@ -186,10 +179,6 @@ int main(int argc, char *argv[])
         app.setGraceTime(graceTime);
     }
 
-    if (parser.isSet(switchUserOption)) {
-        app.setDefaultToSwitchUser(true);
-    }
-
     if (parser.isSet(waylandFdOption)) {
         ok = false;
         const int fd = parser.value(waylandFdOption).toInt(&ok);
